@@ -1,22 +1,16 @@
-import psycopg2.extensions
 from django.db.backends.postgresql import base
 
+from django_prometheus.db.backends.common import get_postgres_cursor_class
 from django_prometheus.db.common import DatabaseWrapperMixin, ExportingCursorWrapper
 
 
-class DatabaseFeatures(base.DatabaseFeatures):
-    """Our database has the exact same features as the base one."""
-
-    pass
-
-
 class DatabaseWrapper(DatabaseWrapperMixin, base.DatabaseWrapper):
-    def get_connection_params(self):
-        conn_params = super().get_connection_params()
-        conn_params["cursor_factory"] = ExportingCursorWrapper(
-            psycopg2.extensions.cursor, self.alias, self.vendor
+    def get_new_connection(self, *args, **kwargs):
+        conn = super().get_new_connection(*args, **kwargs)
+        conn.cursor_factory = ExportingCursorWrapper(
+            conn.cursor_factory or get_postgres_cursor_class(), self.alias, self.vendor
         )
-        return conn_params
+        return conn
 
     def create_cursor(self, name=None):
         # cursor_factory is a kwarg to connect() so restore create_cursor()'s
