@@ -1,6 +1,6 @@
 from prometheus_client import Counter, Histogram
 
-from django_prometheus.conf import NAMESPACE
+from django_prometheus.conf import NAMESPACE, PROMETHEUS_LATENCY_BUCKETS
 
 connections_total = Counter(
     "django_db_new_connections_total",
@@ -18,10 +18,7 @@ connection_errors_total = Counter(
 
 execute_total = Counter(
     "django_db_execute_total",
-    (
-        "Counter of executed statements by database and by vendor, including"
-        " bulk executions."
-    ),
+    ("Counter of executed statements by database and by vendor, including" " bulk executions."),
     ["alias", "vendor"],
     namespace=NAMESPACE,
 )
@@ -46,5 +43,6 @@ query_duration_seconds = Histogram(
     "django_db_query_duration_seconds",
     ("Histogram of query duration by database and vendor."),
     ["alias", "vendor"],
+    buckets=PROMETHEUS_LATENCY_BUCKETS,
     namespace=NAMESPACE,
 )
