@@ -39,9 +39,7 @@ def ExportMigrations():
     # ready.
     from django.db.migrations.executor import MigrationExecutor
 
-    if "default" in connections and (
-        isinstance(connections["default"], DatabaseWrapper)
-    ):
+    if "default" in connections and (isinstance(connections["default"], DatabaseWrapper)):
         # This is the case where DATABASES = {} in the configuration,
         # i.e. the user is not using any databases. Django "helpfully"
         # adds a dummy database and then throws when you try to
