@@ -96,11 +96,15 @@ _tmp_cache_dir = tempfile.mkdtemp()
 
 CACHES = {
     "default": {
-        "BACKEND": "django_prometheus.cache.backends.memcached.MemcachedCache",
+        "BACKEND": "django_prometheus.cache.backends.memcached.PyLibMCCache",
         "LOCATION": "localhost:11211",
     },
-    "memcached": {
-        "BACKEND": "django_prometheus.cache.backends.memcached.MemcachedCache",
+    "memcached.PyLibMCCache": {
+        "BACKEND": "django_prometheus.cache.backends.memcached.PyLibMCCache",
+        "LOCATION": "localhost:11211",
+    },
+    "memcached.PyMemcacheCache": {
+        "BACKEND": "django_prometheus.cache.backends.memcached.PyMemcacheCache",
         "LOCATION": "localhost:11211",
     },
     "filebased": {
@@ -127,11 +131,11 @@ CACHES = {
     },
 }
 
+
 # Internationalization
 LANGUAGE_CODE = "en-us"
 TIME_ZONE = "UTC"
 USE_I18N = True
-USE_L10N = True
 USE_TZ = False
 
 
