@@ -54,9 +54,7 @@ def sql(request):
             {"query": query, "rows": results, "databases": databases},
         )
     else:
-        return TemplateResponse(
-            request, "sql.html", {"query": None, "rows": None, "databases": databases}
-        )
+        return TemplateResponse(request, "sql.html", {"query": None, "rows": None, "databases": databases})
 
 
 def file(request):
